import ActionCard from 'components/Action/ActionCard/ActionCard'
import { useClient } from 'cozy-client'
import { Ecogesture } from 'models'
import React, { useEffect, useState } from 'react'
import ActionService from 'services/action.service'
import { useAppSelector } from 'store/hooks'
import './actionList.scss'

interface ActionListProps {
  setSelectedAction: React.Dispatch<React.SetStateAction<Ecogesture | null>>
  setShowList: React.Dispatch<React.SetStateAction<boolean>>
}

const ActionList = ({ setSelectedAction, setShowList }: ActionListProps) => {
  const client = useClient()
  const {
    global: { fluidTypes },
    profile: { isProfileTypeCompleted },
  } = useAppSelector(state => state.ecolyo)
  const [actions, setActions] = useState<Ecogesture[]>()

  useEffect(() => {
    let subscribed = true
    const getActions = async () => {
      const actionService = new ActionService(client)
      let actionList: Ecogesture[] = []
      if (isProfileTypeCompleted) {
        actionList = await actionService.getCustomActions(fluidTypes)
      } else {
        actionList = await actionService.getDefaultActions()
      }
      if (subscribed) {
        setActions(actionList)
      }
    }
    getActions()
    return () => {
      subscribed = false
    }
  }, [client, isProfileTypeCompleted, fluidTypes])

  return (
    <>
      {actions && (
        <div className="action-list-container">
          {actions.map(action => (
            <ActionCard
              key={action.id}
              action={action}
              setSelectedAction={setSelectedAction}
              setShowList={setShowList}
            />
          ))}
        </div>
      )}
    </>
  )
}

export default ActionList
