import { TextField } from '@material-ui/core'
import Button from '@material-ui/core/Button'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { AccountGRDFData } from 'models'
import React, { useState } from 'react'
import GrdfModalHint from './GrdfModalHint'

export const StepIdentity = ({
  formData,
  setFormData,
}: {
  formData: AccountGRDFData
  setFormData: React.Dispatch<React.SetStateAction<AccountGRDFData>>
}) => {
  const { t } = useI18n()
  const [openHintModal, setOpenHintModal] = useState<boolean>(false)

  return (
    <div className="stepDetails stepIdentity">
      <h2 className="text-22-bold">{t('auth.grdfgrandlyon.identityTitle')}</h2>
      <TextField
        label={t('auth.grdfgrandlyon.firstName')}
        variant="outlined"
        type="text"
        id="firstName"
        name="firstName"
        value={formData.firstname}
        onChange={e =>
          setFormData(prev => ({ ...prev, firstname: e.target.value }))
        }
        required
      />

      <TextField
        label={t('auth.grdfgrandlyon.lastName')}
        variant="outlined"
        type="text"
        id="lastName"
        name="lastName"
        required
        value={formData.lastname}
        onChange={e =>
          setFormData(prev => ({ ...prev, lastname: e.target.value }))
        }
      />

      <TextField
        label={t('auth.grdfgrandlyon.email')}
        variant="outlined"
        type="email"
        id="email"
        name="email"
        required
        value={formData.email}
        onChange={e =>
          setFormData(prev => ({ ...prev, email: e.target.value }))
        }
      />

      <TextField
        label={t('auth.grdfgrandlyon.zipCode')}
        variant="outlined"
        type="number"
        id="zipCode"
        name="zipCode"
        required
        value={formData.postalCode}
        onChange={e =>
          setFormData(prev => ({ ...prev, postalCode: e.target.value }))
        }
      />

      <div className="text-22-bold">{t('auth.grdfgrandlyon.pceTitle')}</div>

      <TextField
        label={t('auth.grdfgrandlyon.pceLabel')}
        variant="outlined"
        id="pce"
        name="pce"
        type="number"
        inputMode="numeric"
        required
        value={formData.pce}
        onChange={e => {
          if (e.target.value.length > 14) return
          setFormData(prev => ({ ...prev, pce: e.target.value }))
        }}
      />

      <Button className="btnText" onClick={() => setOpenHintModal(true)}>
        {t('auth.grdfgrandlyon.pceHint')}
      </Button>
      <GrdfModalHint
        open={openHintModal}
        handleCloseClick={() => setOpenHintModal(false)}
      />
    </div>
  )
}
