import { render, screen, waitFor } from '@testing-library/react'
import { EquipmentType } from 'enums'
import React from 'react'
import { Provider } from 'react-redux'
import { mockProfileEcogesture } from 'tests/__mocks__/profileEcogesture.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import EcogestureFormEquipment from './EcogestureFormEquipment'

jest.mock('../EquipmentIcon/EquipmentIcon', () => 'mock-equipment-icon')

describe('EcogestureFormEquipment component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', async () => {
    const { container } = render(
      <Provider store={store}>
        <EcogestureFormEquipment
          currentProfileEcogesture={mockProfileEcogesture}
          setPreviousStep={jest.fn()}
          setNextStepEcogestureForm={jest.fn()}
        />
      </Provider>
    )
    expect(container).toMatchSnapshot()
  })

  it('should find X equipments', async () => {
    const { container } = render(
      <Provider store={store}>
        <EcogestureFormEquipment
          currentProfileEcogesture={mockProfileEcogesture}
          setPreviousStep={jest.fn()}
          setNextStepEcogestureForm={jest.fn()}
        />
      </Provider>
    )
    await waitFor(() => null, { container })
    const equipments = screen.getAllByRole('listitem')
    console.log(equipments.length)
    expect(equipments[0]).not.toBeDisabled()
    expect(equipments.length).toBe(Object.keys(EquipmentType).length)
  })

  it('should click on disabled back button', async () => {
    const { container } = render(
      <Provider store={store}>
        <EcogestureFormEquipment
          currentProfileEcogesture={mockProfileEcogesture}
          setPreviousStep={jest.fn()}
          setNextStepEcogestureForm={jest.fn()}
        />
      </Provider>
    )

    expect(
      container.getElementsByClassName('icons-container').length
    ).toBeTruthy()
    expect(
      screen.getByLabelText('profile_type.accessibility.button_end')
    ).toBeDisabled()
  })
})
