import { act, render, screen } from '@testing-library/react'
import userEvent from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import ExplorationFinished from './ExplorationFinished'

const mockNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockNavigate,
}))

describe('ExplorationFinished', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly and redirect on click', async () => {
    const { container } = render(
      <Provider store={store}>
        <ExplorationFinished userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(screen.getByRole('img')).toBeInTheDocument()
    expect(container.getElementsByClassName('congratulation')[0]).toBeTruthy()
    expect(container.getElementsByClassName('exploration-earn')[0]).toBeTruthy()
    expect(
      screen.getByText(userChallengeData[0].exploration.message_success)
    ).toBeInTheDocument()
    await act(async () => {
      await userEvent.click(screen.getByText('exploration.button_confirm'))
    })
    expect(mockNavigate).toHaveBeenCalledWith(-1)
  })
})
