import Button from '@material-ui/core/Button'
import explorationIcon from 'assets/icons/visu/exploration/shield.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import StarsContainer from 'components/CommonKit/StarsContainer/StarsContainer'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import {
  UserChallengeUpdateFlag,
  UserExplorationState,
  UserExplorationType,
} from 'enums'
import { UserChallenge } from 'models'
import React from 'react'
import { useNavigate } from 'react-router-dom'
import ChallengeService from 'services/challenge.service'
import { updateUserChallengeList } from 'store/challenge/challenge.slice'
import { useAppDispatch } from 'store/hooks'
import './explorationOngoing.scss'

interface ExplorationOngoingProps {
  userChallenge: UserChallenge
}

const ExplorationOngoing = ({ userChallenge }: ExplorationOngoingProps) => {
  const { t } = useI18n()
  const client = useClient()
  const dispatch = useAppDispatch()
  const navigate = useNavigate()

  const challengeService = new ChallengeService(client)

  const startExploration = async () => {
    if (userChallenge.exploration.state !== UserExplorationState.ONGOING) {
      const updatedChallenge = await challengeService.updateUserChallenge(
        userChallenge,
        UserChallengeUpdateFlag.EXPLORATION_START
      )
      dispatch(updateUserChallengeList(updatedChallenge))
    }
    navigate('/challenges')
  }

  const validExploration = async () => {
    const updatedChallenge = await challengeService.updateUserChallenge(
      userChallenge,
      UserChallengeUpdateFlag.EXPLORATION_DONE
    )
    dispatch(updateUserChallengeList(updatedChallenge))
    navigate('/challenges')
  }
  const renderButton = () => {
    switch (userChallenge.exploration.type) {
      case UserExplorationType.DECLARATIVE:
        return (
          <div className="button-start">
            <Button
              aria-label={t('exploration.accessibility.button_already_done')}
              onClick={validExploration}
              className="btnSecondary"
            >
              {t('exploration.button_already_done')}
            </Button>
            <Button
              aria-label={t('exploration.accessibility.button_already_done')}
              onClick={() => navigate(-1)}
              className="btnSecondary"
            >
              {t('exploration.button_come_back')}
            </Button>
          </div>
        )
      case UserExplorationType.ACTION:
      case UserExplorationType.ECOGESTURE:
      case UserExplorationType.CONSUMPTION:
        return (
          <Button
            aria-label={t('exploration.accessibility.button_start')}
            onClick={startExploration}
            className="btnSecondary"
          >
            {t('exploration.button_start')}
          </Button>
        )
    }
  }

  return (
    <>
      <div className="exploration-container">
        <div className="exploration-begin-container">
          <StyledIcon
            className="exploration-icon"
            icon={explorationIcon}
            size={180}
          />
          <StarsContainer
            result={userChallenge.progress.explorationProgress}
            isQuizBegin={true}
          />
          <div className="exploration-explanation text-18-bold">
            <div>{userChallenge.exploration.description}</div>
            <div>{userChallenge.exploration.complementary_description}</div>
          </div>
          {renderButton()}
        </div>
      </div>
    </>
  )
}

export default ExplorationOngoing
