import { act, render, screen } from '@testing-library/react'
import userEvent from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import UsageEventService from 'services/usageEvent.service'
import { mockProfileType } from 'tests/__mocks__/profileType.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import ProfileTypeFinished from './ProfileTypeFinished'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useLocation: () => ({
    pathname: '/ecogesture-form',
  }),
  useNavigate: () => mockedNavigate,
}))

jest.mock('services/usageEvent.service')
UsageEventService.addEvent = jest.fn()

jest.mock('services/profileTypeEntity.service', () => {
  return jest.fn(() => ({
    getAllProfileTypes: jest.fn(),
    deleteProfileTypes: jest.fn(),
  }))
})

describe('ProfileTypeFinished component', () => {
  const store = createMockEcolyoStore()

  it('should be rendered correctly', async () => {
    const { container } = render(
      <Provider store={store}>
        <ProfileTypeFinished profileType={mockProfileType} />
      </Provider>
    )
    expect(
      container.getElementsByClassName('profile-type-finished-card')[0]
    ).toBeInTheDocument()
  })
  it('should go to ecogesture selection', async () => {
    render(
      <Provider store={store}>
        <ProfileTypeFinished profileType={mockProfileType} />
      </Provider>
    )
    await act(async () => {
      await userEvent.click(
        screen.getByLabelText('profile_type.accessibility.button_validate')
      )
    })
    expect(mockedNavigate).toHaveBeenCalledWith('/ecogesture-selection')
  })
})
