import { EquipmentType, Room, Season } from 'enums'
import { Ecogesture } from 'models'

export const defaultEcogestureData: Ecogesture[] = [
  {
    _id: 'ECOGESTURE0010',
    id: 'ECOGESTURE0010',
    usage: 3,
    fluidTypes: [0, 2],
    shortName: 'Poings de glace',
    longName: "Je me lave les mains à l'eau froide.",
    longDescription:
      'Bien souvent le temps de se laver les mains est trop court pour que l’eau chaude arrive jusqu’à soi ! Donc autant ne prendre que de l’eau froide pour se les laver.',
    impactLevel: 3,
    efficiency: 1.5,
    difficulty: 1,
    room: [Room.BATHROOM, Room.KITCHEN],
    season: Season.NONE,
    equipment: false,
    equipmentType: [],
    equipmentInstallation: true,
    investment: null,
    action: true,
    actionName: "Je me lave les mains uniquement à l'eau froide.",
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
  },
  {
    _id: 'ECOGESTURE0014',
    id: 'ECOGESTURE0014',
    usage: 5,
    fluidTypes: [0],
    shortName: 'Chat échaudé',
    longName:
      'J’attends que les plats chauds aient refroidi avant de les mettre au réfrigérateur et je les couvre.',
    longDescription:
      'En plaçant des plats chauds au réfrigérateur, vous réchauffez l’enceinte de l’appareil, ce qui entraîne une surconsommation. De plus, si les plats ne sont pas couverts, de la vapeur d’eau va se former et provoquer l’apparition du givre. Et couvrir les plats, c’est aussi éviter que les bactéries et les odeurs ne se répandent.',
    impactLevel: 2,
    efficiency: 1,
    difficulty: 1,
    room: [Room.KITCHEN],
    season: Season.NONE,

    equipment: false,
    equipmentType: [],
    equipmentInstallation: true,
    investment: null,
    action: true,
    actionName:
      'J’attends que les plats chauds aient refroidi avant de les mettre au réfrigérateur et je les couvre.',
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
  },
  {
    id: 'ECOGESTURE0030',
    _id: 'ECOGESTURE0030',
    usage: 5,
    fluidTypes: [0],
    shortName: 'Reine du Puzzle',
    longName:
      'J’optimise le rangement dans mon réfrigérateur et/ou congélateur.',
    longDescription:
      "La partie la plus froide ne se situe pas toujours au même endroit selon l’appareil : dans le haut des réfrigérateurs traditionnels, dans le bas des combinés 2 portes. Dans les réfrigérateurs à froid ventilé, les températures sont plus homogènes. Regardez la notice de votre réfrigérateur pour identifier les différentes zones de température et ainsi ranger chaque aliment à sa place. Enlevez les produits de leur emballage d'origine (film plastique, carton, etc.) qui filtrent le froid. Rangez les denrées de façon rationnelle pour y accéder plus rapidement et aussi pour pouvoir refermer plus rapidement la porte. Surtout, n’obstruez pas le thermostat car s’il est recouvert de givre ou de produits, il ne détectera pas la température correctement et l’abaissera plus que nécessaire.",
    impactLevel: 1,
    efficiency: 0.5,
    difficulty: 1,
    room: [Room.KITCHEN],
    season: Season.NONE,
    equipment: false,
    equipmentType: [],
    equipmentInstallation: true,
    investment: null,
    action: true,
    actionName:
      'J’optimise le rangement dans mon réfrigérateur et/ou congélateur.',
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
  },
]

export const ecogestureDefault: Ecogesture = {
  _id: 'ECOGESTURE0010',
  id: 'ECOGESTURE0010',
  usage: 3,
  fluidTypes: [0, 2],
  shortName: 'Poings de glace',
  longName: "Je me lave les mains à l'eau froide.",
  longDescription:
    'Bien souvent le temps de se laver les mains est trop court pour que l’eau chaude arrive jusqu’à soi ! Donc autant ne prendre que de l’eau froide pour se les laver.',
  impactLevel: 3,
  efficiency: 1.5,
  difficulty: 1,
  room: [Room.BATHROOM, Room.KITCHEN],
  season: Season.NONE,
  equipment: false,
  equipmentType: [],
  equipmentInstallation: true,
  investment: null,
  action: true,
  actionName: "Je me lave les mains uniquement à l'eau froide.",
  actionDuration: 3,
  doing: false,
  objective: false,
  viewedInSelection: false,
}

export const AllEcogestureData: Ecogesture[] = [
  {
    _id: 'ECOGESTURE0001',
    id: 'ECOGESTURE0001',
    usage: 1,
    fluidTypes: [0, 2],
    shortName: 'Bonhomme de neige',
    longName:
      "Je baisse le chauffage en mode hors gel lorsque je m'absente plus de 2 jours.",
    longDescription:
      'On se demande parfois si cela vaut le coup de "couper le chauffage" quand on s’absente… dès qu’il s’agit d’un week-end la réponse est « oui sûrement » ! Attention cependant au retour à ne pas faire de la surchauffe ! L’idéal est bien évidemment de régler sa programmation pour que le chauffage se relance quelques heures avant votre retour…',
    impactLevel: 8,
    efficiency: 5,
    difficulty: 1,
    room: [Room.ALL],
    season: Season.WINTER,
    equipment: false,
    equipmentType: [],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
  },
  {
    _id: 'ECOGESTURE0002',
    id: 'ECOGESTURE0002',
    usage: 2,
    fluidTypes: [0],
    shortName: 'Coup de vent',
    longName: 'Je ferme mes fenêtres quand la climatisation est en marche',
    longDescription:
      "Cela permet de garder la fraîcheur à l'intérieur. Le climatiseur n'est pas là pour refroidir la rue mais bien la pièce.",
    impactLevel: 8,
    efficiency: 1,
    difficulty: 1,
    room: [Room.ALL],
    season: Season.SUMMER,
    equipment: true,
    equipmentType: [EquipmentType.AIR_CONDITIONING],
    equipmentInstallation: true,
    investment: null,
    action: false,
    actionName: null,
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
  },
  {
    _id: 'ECOGESTURE0003',
    id: 'ECOGESTURE0003',
    usage: 1,
    fluidTypes: [0, 2],
    shortName: 'Passe-Pas-Partout',
    longName:
      'Je ferme les portes entre les pièces chauffées et moins chauffées.',
    longDescription:
      'Vous pouvez économiser 6 % de l’énergie nécessaire au chauffage en fermant les portes entre les pièces qui ne sont pas chauffées à la même température. Utilisez des “boudins de porte” pour éviter les courants d’air !',
    impactLevel: 8,
    efficiency: 5,
    difficulty: 2,
    room: [Room.ALL],
    season: Season.WINTER,
    equipment: false,
    equipmentType: [],
    equipmentInstallation: true,
    investment: null,
    action: true,
    actionName:
      'Je ferme les portes entre les pièces chauffées et moins chauffées.',
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
  },
  {
    _id: 'ECOGESTURE0004',
    id: 'ECOGESTURE0004',
    usage: 3,
    fluidTypes: [1],
    shortName: 'Déesse des eaux',
    longName: "Je coupe l'eau de la douche pendant que je me savonne.",
    longDescription:
      "Si vous n’êtes pas frileux, coupez l'eau pendant que vous vous savonnez : l'économie en eau peut aller jusqu'à 50% !",
    impactLevel: 5,
    efficiency: 2.5,
    difficulty: 1,
    room: [Room.BATHROOM],
    season: Season.NONE,
    equipment: false,
    equipmentType: [],
    equipmentInstallation: true,
    investment: null,
    action: true,
    actionName: "Je coupe l'eau de la douche pendant que je me savonne.",
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
  },
  {
    _id: 'ECOGESTURE0005',
    id: 'ECOGESTURE0005',
    usage: 4,
    fluidTypes: [1],
    shortName: 'NoNiagara',
    longName: 'Je ferme l’eau du robinet quand je me lave les dents.',
    longDescription:
      "Un robinet qui coule inutilement pendant 2 minutes, c'est 25 litres d'eau gaspillés. Si ce gaspillage est fait tous les jours, c'est presque 10 000 litres perdus sur l'année.",
    impactLevel: 5,
    efficiency: 2.5,
    difficulty: 1,
    room: [Room.BATHROOM],
    season: Season.NONE,
    equipment: false,
    equipmentType: [],
    equipmentInstallation: true,
    investment: null,
    action: true,
    actionName: 'Je ferme l’eau du robinet quand je me lave les dents.',
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
  },
  {
    _id: 'ECOGESTURE0006',
    id: 'ECOGESTURE0006',
    usage: 1,
    fluidTypes: [0, 2],
    shortName: "Plumeau d'or",
    longName: 'Je dépoussière mes radiateurs au moins une fois par an.',
    longDescription:
      "La poussière bride les performances des radiateurs, hydrauliques ou électriques : les dépoussiérer permet une meilleure diffusion de la chaleur. Avec une meilleure efficacité, il vous sera alors possible d'avoir aussi chaud en consommant moins (si vous en avez profité pour baisser un peu votre thermostat bien sûr).",
    impactLevel: 3,
    efficiency: 1.5,
    difficulty: 1,
    room: [Room.ALL],
    season: Season.WINTER,
    equipment: false,
    equipmentType: [],
    equipmentInstallation: true,
    investment: null,
    action: true,
    actionName: 'Je dépoussière mes radiateurs.',
    actionDuration: 3,
    doing: false,
    objective: false,
    viewedInSelection: false,
  },
]
